@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::Yancy;
-our $VERSION = '1.077';
+our $VERSION = '1.078';
 # ABSTRACT: Embed a simple admin CMS into your Mojolicious application
 
 #pod =head1 SYNOPSIS
@@ -18,7 +18,7 @@ our $VERSION = '1.077';
 #pod =head1 CONFIGURATION
 #pod
 #pod For getting started with a configuration for Yancy, see
-#pod L<Yancy::Help::Config>.
+#pod the L<"Yancy Guides"|Yancy::Guides>.
 #pod
 #pod Additional configuration keys accepted by the plugin are:
 #pod
@@ -27,7 +27,7 @@ our $VERSION = '1.077';
 #pod =item backend
 #pod
 #pod In addition to specifying the backend as a single URL (see L<"Database
-#pod Backend"|Yancy::Help::Config/Database Backend>), you can specify it as
+#pod Backend"|Yancy::Guides::Schema/Database Backend>), you can specify it as
 #pod a hashref of C<< class => $db >>. This allows you to share database
 #pod connections.
 #pod
@@ -1057,7 +1057,7 @@ Mojolicious::Plugin::Yancy - Embed a simple admin CMS into your Mojolicious appl
 
 =head1 VERSION
 
-version 1.077
+version 1.078
 
 =head1 SYNOPSIS
 
@@ -1075,7 +1075,7 @@ quickly build your own application.
 =head1 CONFIGURATION
 
 For getting started with a configuration for Yancy, see
-L<Yancy::Help::Config>.
+the L<"Yancy Guides"|Yancy::Guides>.
 
 Additional configuration keys accepted by the plugin are:
 
@@ -1084,7 +1084,7 @@ Additional configuration keys accepted by the plugin are:
 =item backend
 
 In addition to specifying the backend as a single URL (see L<"Database
-Backend"|Yancy::Help::Config/Database Backend>), you can specify it as
+Backend"|Yancy::Guides::Schema/Database Backend>), you can specify it as
 a hashref of C<< class => $db >>. This allows you to share database
 connections.
 
