@@ -1,5 +1,5 @@
 package Yancy::Controller::Yancy;
-our $VERSION = '1.077';
+our $VERSION = '1.078';
 # ABSTRACT: Basic controller for displaying content
 
 #pod =head1 SYNOPSIS
@@ -158,8 +158,8 @@ our $VERSION = '1.077';
 #pod An array reference of columns to display in the table. The same as
 #pod C<x-list-columns> in the schema configuration. Defaults to
 #pod C<x-list-columns> in the schema configuration or all of the schema's
-#pod columns in C<x-order> order. See L<Yancy::Help::Config/Extended
-#pod Collection Configuration> for more information.
+#pod columns in C<x-order> order. See L<Yancy::Guides::Schema/Documenting
+#pod Your Schema> for more information.
 #pod
 #pod =item table
 #pod
@@ -487,8 +487,8 @@ sub get {
 #pod a schema. If the user is making a C<GET> request, they will simply
 #pod be shown the template. If the user is making a C<POST> or C<PUT>
 #pod request, the form parameters will be read, the data will be validated
-#pod against L<the schema configuration|Yancy::Help::Config/Data
-#pod Schema>, and the user will either be shown the form again with the
+#pod against L<the schema configuration|Yancy::Guides::Schema>, 
+#pod and the user will either be shown the form again with the
 #pod result of the form submission (success or failure) or the user will be
 #pod forwarded to another place.
 #pod
@@ -1226,7 +1226,7 @@ Yancy::Controller::Yancy - Basic controller for displaying content
 
 =head1 VERSION
 
-version 1.077
+version 1.078
 
 =head1 SYNOPSIS
 
@@ -1490,8 +1490,8 @@ This route creates a new item or updates an existing item in
 a schema. If the user is making a C<GET> request, they will simply
 be shown the template. If the user is making a C<POST> or C<PUT>
 request, the form parameters will be read, the data will be validated
-against L<the schema configuration|Yancy::Help::Config/Data
-Schema>, and the user will either be shown the form again with the
+against L<the schema configuration|Yancy::Guides::Schema>, 
+and the user will either be shown the form again with the
 result of the form submission (success or failure) or the user will be
 forwarded to another place.
 
@@ -1932,8 +1932,8 @@ for configuration:
 An array reference of columns to display in the table. The same as
 C<x-list-columns> in the schema configuration. Defaults to
 C<x-list-columns> in the schema configuration or all of the schema's
-columns in C<x-order> order. See L<Yancy::Help::Config/Extended
-Collection Configuration> for more information.
+columns in C<x-order> order. See L<Yancy::Guides::Schema/Documenting
+Your Schema> for more information.
 
 =item table
 
