@@ -1,5 +1,5 @@
 package Yancy::Plugin::Editor;
-our $VERSION = '1.077';
+our $VERSION = '1.078';
 # ABSTRACT: Yancy content editor, admin, and management application
 
 #pod =head1 SYNOPSIS
@@ -50,8 +50,7 @@ our $VERSION = '1.077';
 #pod =head2 openapi
 #pod
 #pod Instead of L</schema>, you can pass a full OpenAPI spec to this editor.
-#pod See L<Yancy::Help::Config> for more details on how to build the OpenAPI
-#pod spec.
+#pod This is deprecated; see L<Yancy::Guides::Upgrading>.
 #pod
 #pod =head2 default_controller
 #pod
@@ -176,7 +175,7 @@ our $VERSION = '1.077';
 #pod
 #pod =head1 SEE ALSO
 #pod
-#pod L<Yancy::Help::Config>, L<Mojolicious::Plugin::Yancy>, L<Yancy>
+#pod L<Yancy::Guides::Schema>, L<Mojolicious::Plugin::Yancy>, L<Yancy>
 #pod
 #pod =cut
 
@@ -697,7 +696,7 @@ Yancy::Plugin::Editor - Yancy content editor, admin, and management application
 
 =head1 VERSION
 
-version 1.077
+version 1.078
 
 =head1 SYNOPSIS
 
@@ -747,8 +746,7 @@ from the backend.
 =head2 openapi
 
 Instead of L</schema>, you can pass a full OpenAPI spec to this editor.
-See L<Yancy::Help::Config> for more details on how to build the OpenAPI
-spec.
+This is deprecated; see L<Yancy::Guides::Upgrading>.
 
 =head2 default_controller
 
@@ -872,7 +870,7 @@ or L<filing a bug report or feature request|https://github.com/preaction/Yancy/i
 
 =head1 SEE ALSO
 
-L<Yancy::Help::Config>, L<Mojolicious::Plugin::Yancy>, L<Yancy>
+L<Yancy::Guides::Schema>, L<Mojolicious::Plugin::Yancy>, L<Yancy>
 
 =head1 AUTHOR
 
